HEALTH = {
    "big rock": 45,
    "bonsai pot": 24,
    "blue dye": 6,
    "bluebell": 10,
    "blueprint": 8,
    "bowl": 6,
    "brick": 12,
    "campfire": 8,
    "carroot": 8,
    "carrot": 4,
    "clay": 12,
    "coal ore": 20,
    "coal": 8,
    "composter": 8,
    "copper brick": 12,
    "copper brick floor": 8,
    "corpse": 1,
    "dirt": 5,
    "fertilizer": 5,
    "flint axe": 6,
    "flint hammer": 10,
    "flint pickaxe": 6,
    "flint shovel": 6,
    "flint sword": 6,
    "flint": 16,
    "glass": 8,
    "glass key": 1,
    "glass lock": 1,
    "ice": 12,
    "junk": 1,
    "left": 1,
    "log floor": 12,
    "log": 8,
    "manual press": 12,
    "masonry bench": 12,
    "mushroom block": 5,
    "mushroom door": 10,
    "mushroom floor": 8,
    "mushroom shaper": 13,
    "mushroom stew": 6,
    "mushroom": 10,
    "obelisk": 1,
    "paper": 8,
    "pebble": 8,
    "plant bouquet": 6,
    "player": 20,
    "rabbit adult": 10,
    "rabbit child": 6,
    "rabbit fur": 8,
    "rabbit hole": 1,
    "rabbit meat": 6,
    "roasted mushroom": 8,
    "roasted rabbit meat": 10,
    "rock": 20,
    "rock axe": 10,
    "rock pickaxe": 10,
    "rock shovel": 10,
    "rock sword": 10,
    "sand": 6,
    "sapling": 4,
    "sawbench": 12,
    "small barrel": 10,
    "small crate": 10,
    "spore": 4,
    "stick": 4,
    "stone brick": 16,
    "stone": 16,
    "tree": 10,
    "treeling": 9,
    "up": 1,
    "void": 1,
    "water": 8,
    "wood door": 8,
    "wood floor": 6,
    "wood pulp": 6,
    "wood": 4,
    "wooden bed": 12,
    "wooden table": 8,
    "workbench": 5,
}