ATTRIBUTES = {
    "big rock": {"multi", "no_pickup"},
    "bonsai pot": {"open", "machine"},
    "campfire": {"open", "craft", "light"},
    "carrot": {"grow", "eat"},
    "carroot": {"no_pickup"},
    "coal ore": {"no_pickup"},
    "compost": {"fertilize"},
    "composter": {"open", "machine", "value"},
    "fertilizer": {"fertilize"},
    "glass key": {"key"},
    "glass lock": {"lock"},
    "manual press": {"open", "craft", "multi"},
    "masonry bench": {"open", "craft", "multi"},
    "mushroom": {"eat"},
    "mushroom shaper": {"open", "craft"},
    "mushroom stew": {"eat"},
    "rabbit adult": {"rabbit", "no_pickup"},
    "rabbit child": {"grow", "rabbit", "no_pickup"},
    "rabbit meat": {"eat"},
    "roasted mushroom": {"eat"},
    "roasted rabbit meat": {"eat"},
    "sapling": {"grow"},
    "sawbench": {"open", "craft", "multi"},
    "small barrel": {"open", "store"},
    "small crate": {"open", "store"},
    "spore": {"grow"},
    "tree": {"no_pickup"},
    "treeling": {"grow", "no_pickup"},
    "wooden bed": {"sleep", "multi"},
    "wooden table": {"store", "table"},
    "workbench": {"open", "craft"},

    # Special tiles
    "left": {"point", "no_pickup"},
    "up": {"point", "no_pickup"},
    "player": {"open", "craft", "no_pickup"},
    "junk": {"no_pickup"},
    "corpse": {"no_pickup"},
    "obelisk": {"multi", "no_pickup"},
}