RESISTANCE = {
    "big rock": 2,
    "bonsai pot": 2,
    "brick": 1,
    "clay": 1,
    "coal": 1,
    "coal ore": 2,
    "composter": 1,
    "copper brick": 3,
    "copper brick floor": 3,
    "ice": 1,
    "manual press": 1,
    "masonry bench": 1,
    "mushroom block": 1,
    "mushroom door": 1,
    "mushroom floor": 1,
    "mushroom shaper": 2,
    "pebble": 1,
    "rabbit adult": 1,
    "rock": 1,
    "sawbench": 1,
    "stone": 1,
    "stone brick": 1,
    "tree": 1,
}