TOOL_REQUIRED = {
    "big rock": "pickaxe",
    "bluebell": "shovel",
    "bonsai pot": "axe",
    "brick": "pickaxe",
    "campfire": "axe",
    "carrot": "shovel",
    "carroot": "shovel",
    "clay": "shovel",
    "coal": "pickaxe",
    "coal ore": "pickaxe",
    "composter": "axe",
    "copper brick": "pickaxe",
    "copper brick floor": "pickaxe",
    "dirt": "shovel",
    "flint": "pickaxe",
    "ice": "pickaxe",
    "log": "axe",
    "log floor": "axe",
    "manual press": "axe",
    "masonry bench": "pickaxe",
    "mushroom": "axe",
    "mushroom block": "hammer",
    "mushroom door": "hammer",
    "mushroom door open": "hammer",
    "mushroom floor": "hammer",
    "mushroom shaper": "hammer",
    "pebble": "pickaxe",
    "player": "sword",
    "rabbit adult": "sword",
    "rabbit child": "sword",
    "rock": "pickaxe",
    "sand": "shovel",
    "sapling": "shovel",
    "sawbench": "axe",
    "small crate": "axe",
    "spore": "shovel",
    "stick": "axe",
    "stone": "pickaxe",
    "stone brick": "pickaxe",
    "tree": "axe",
    "treeling": "axe",
    "wood": "axe",
    "wood door": "axe",
    "wood door open": "axe",
    "wood floor": "axe",
    "wood pulp": "shovel",
}
TOOL_EFFICIENCY = {
    "flint": 1, 
    "rock": 2
}